<?php

namespace Drupal\webform_gpn\Element;

use Drupal\Core\Render\Element;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element\Textfield;

/**
 * Provides a 'webform_georgian_personal_number'.
 *
 * @FormElement("webform_georgian_personal_number")
 */
class WebformGeorgianPersonalNumber extends Textfield {

  /**
   * {@inheritdoc}
   */
  public function getInfo(): array {
    $class = get_class($this);

    return [
      '#input' => TRUE,
      '#type' => 'textfield',
      '#size' => 11,
      '#process' => [
        [$class, 'processGeorgianPersonalNumber'],
      ],
      '#element_validate' => [
        [$class, 'validateGeorgianPersonalNumber'],
      ],
      '#pre_render' => [
        [$class, 'preRenderGeorgianPersonalNumber'],
      ],
      '#theme' => 'input__webform_example_element',
      '#theme_wrappers' => ['form_element'],
    ];
  }

  /**
   * Processes 'webform_iban_field' element.
   *
   * @param array $element
   *   The element.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   * @param array $complete_form
   *   The complete form.
   *
   * @return array
   *   Returns the element.
   */
  public static function processGeorgianPersonalNumber(array &$element, FormStateInterface $form_state, array &$complete_form) {
    return $element;
  }

  /**
   * Webform element validation handler.
   */
  public static function validateGeorgianPersonalNumber(array &$element, FormStateInterface $form_state, array &$complete_form): void {
    $gpn = $form_state->getValue($element['#webform_key']);
    if (!preg_match('/^\d{11}$/', $gpn)) {
      $form_state->setError($element, $element['#error_message']);
    }
  }

  /**
   * Prepares a render element for theme_element().
   */
  public static function preRenderGeorgianPersonalNumber(array $element) {
    $element['#attributes']['type'] = 'text';
    $element['#attributes']['data-inputmask-mask'] = '99999999999';
    $element['#attached']['library'][] = 'webform/webform.element.inputmask';
    Element::setAttributes($element, [
      'id',
      'name',
      'value',
      'size',
      'maxlength',
      'placeholder',
    ]);
    static::setAttributes($element, [
      'form-text',
      'gpn',
      'js-webform-input-mask',
    ]);
    return $element;
  }

}
